/****************************************************************************
** Meta object code from reading C++ file 'CdDeviceInterface.h'
**
** Created by: The Qt Meta Object Compiler version 69 (Qt 6.11.1)
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#include "CdDeviceInterface.h"
#include <QtCore/qmetatype.h>
#include <QtCore/QList>

#include <QtCore/qtmochelpers.h>

#include <memory>


#include <QtCore/qxptype_traits.h>
#if !defined(Q_MOC_OUTPUT_REVISION)
#error "The header file 'CdDeviceInterface.h' doesn't include <QObject>."
#elif Q_MOC_OUTPUT_REVISION != 69
#error "This file was generated using the moc from 6.11.1. It"
#error "cannot be used with the include files from this version of Qt."
#error "(The moc has changed too much.)"
#endif

#ifndef Q_CONSTINIT
#define Q_CONSTINIT
#endif

QT_WARNING_PUSH
QT_WARNING_DISABLE_DEPRECATED
QT_WARNING_DISABLE_GCC("-Wuseless-cast")
namespace {
struct qt_meta_tag_ZN17CdDeviceInterfaceE_t {};
} // unnamed namespace

template <> constexpr inline auto CdDeviceInterface::qt_create_metaobjectdata<qt_meta_tag_ZN17CdDeviceInterfaceE_t>()
{
    namespace QMC = QtMocConstants;
    QtMocHelpers::StringRefStorage qt_stringData {
        "CdDeviceInterface",
        "Changed",
        "",
        "AddProfile",
        "QDBusPendingReply<>",
        "relation",
        "QDBusObjectPath",
        "object_path",
        "GetProfileForQualifiers",
        "QDBusPendingReply<QDBusObjectPath>",
        "qualifiers",
        "GetProfileRelation",
        "QDBusPendingReply<QString>",
        "MakeProfileDefault",
        "profile_path",
        "ProfilingInhibit",
        "ProfilingUninhibit",
        "RemoveProfile",
        "SetEnabled",
        "enabled",
        "SetProperty",
        "property_name",
        "property_value",
        "Colorspace",
        "Created",
        "DeviceId",
        "Embedded",
        "Enabled",
        "Format",
        "Kind",
        "Metadata",
        "CdStringMap",
        "Mode",
        "Model",
        "Modified",
        "Owner",
        "Profiles",
        "QList<QDBusObjectPath>",
        "ProfilingInhibitors",
        "Scope",
        "Seat",
        "Serial",
        "Vendor"
    };

    QtMocHelpers::UintData qt_methods {
        // Signal 'Changed'
        QtMocHelpers::SignalData<void()>(1, 2, QMC::AccessPublic, QMetaType::Void),
        // Slot 'AddProfile'
        QtMocHelpers::SlotData<QDBusPendingReply<>(const QString &, const QDBusObjectPath &)>(3, 2, QMC::AccessPublic, 0x80000000 | 4, {{
            { QMetaType::QString, 5 }, { 0x80000000 | 6, 7 },
        }}),
        // Slot 'GetProfileForQualifiers'
        QtMocHelpers::SlotData<QDBusPendingReply<QDBusObjectPath>(const QStringList &)>(8, 2, QMC::AccessPublic, 0x80000000 | 9, {{
            { QMetaType::QStringList, 10 },
        }}),
        // Slot 'GetProfileRelation'
        QtMocHelpers::SlotData<QDBusPendingReply<QString>(const QDBusObjectPath &)>(11, 2, QMC::AccessPublic, 0x80000000 | 12, {{
            { 0x80000000 | 6, 7 },
        }}),
        // Slot 'MakeProfileDefault'
        QtMocHelpers::SlotData<QDBusPendingReply<>(const QDBusObjectPath &)>(13, 2, QMC::AccessPublic, 0x80000000 | 4, {{
            { 0x80000000 | 6, 14 },
        }}),
        // Slot 'ProfilingInhibit'
        QtMocHelpers::SlotData<QDBusPendingReply<>()>(15, 2, QMC::AccessPublic, 0x80000000 | 4),
        // Slot 'ProfilingUninhibit'
        QtMocHelpers::SlotData<QDBusPendingReply<>()>(16, 2, QMC::AccessPublic, 0x80000000 | 4),
        // Slot 'RemoveProfile'
        QtMocHelpers::SlotData<QDBusPendingReply<>(const QDBusObjectPath &)>(17, 2, QMC::AccessPublic, 0x80000000 | 4, {{
            { 0x80000000 | 6, 7 },
        }}),
        // Slot 'SetEnabled'
        QtMocHelpers::SlotData<QDBusPendingReply<>(bool)>(18, 2, QMC::AccessPublic, 0x80000000 | 4, {{
            { QMetaType::Bool, 19 },
        }}),
        // Slot 'SetProperty'
        QtMocHelpers::SlotData<QDBusPendingReply<>(const QString &, const QString &)>(20, 2, QMC::AccessPublic, 0x80000000 | 4, {{
            { QMetaType::QString, 21 }, { QMetaType::QString, 22 },
        }}),
    };
    QtMocHelpers::UintData qt_properties {
        // property 'Colorspace'
        QtMocHelpers::PropertyData<QString>(23, QMetaType::QString, QMC::DefaultPropertyFlags),
        // property 'Created'
        QtMocHelpers::PropertyData<qulonglong>(24, QMetaType::ULongLong, QMC::DefaultPropertyFlags),
        // property 'DeviceId'
        QtMocHelpers::PropertyData<QString>(25, QMetaType::QString, QMC::DefaultPropertyFlags),
        // property 'Embedded'
        QtMocHelpers::PropertyData<bool>(26, QMetaType::Bool, QMC::DefaultPropertyFlags),
        // property 'Enabled'
        QtMocHelpers::PropertyData<bool>(27, QMetaType::Bool, QMC::DefaultPropertyFlags),
        // property 'Format'
        QtMocHelpers::PropertyData<QString>(28, QMetaType::QString, QMC::DefaultPropertyFlags),
        // property 'Kind'
        QtMocHelpers::PropertyData<QString>(29, QMetaType::QString, QMC::DefaultPropertyFlags),
        // property 'Metadata'
        QtMocHelpers::PropertyData<CdStringMap>(30, 0x80000000 | 31, QMC::DefaultPropertyFlags | QMC::EnumOrFlag),
        // property 'Mode'
        QtMocHelpers::PropertyData<QString>(32, QMetaType::QString, QMC::DefaultPropertyFlags),
        // property 'Model'
        QtMocHelpers::PropertyData<QString>(33, QMetaType::QString, QMC::DefaultPropertyFlags),
        // property 'Modified'
        QtMocHelpers::PropertyData<qulonglong>(34, QMetaType::ULongLong, QMC::DefaultPropertyFlags),
        // property 'Owner'
        QtMocHelpers::PropertyData<uint>(35, QMetaType::UInt, QMC::DefaultPropertyFlags),
        // property 'Profiles'
        QtMocHelpers::PropertyData<QList<QDBusObjectPath>>(36, 0x80000000 | 37, QMC::DefaultPropertyFlags | QMC::EnumOrFlag),
        // property 'ProfilingInhibitors'
        QtMocHelpers::PropertyData<QStringList>(38, QMetaType::QStringList, QMC::DefaultPropertyFlags),
        // property 'Scope'
        QtMocHelpers::PropertyData<QString>(39, QMetaType::QString, QMC::DefaultPropertyFlags),
        // property 'Seat'
        QtMocHelpers::PropertyData<QString>(40, QMetaType::QString, QMC::DefaultPropertyFlags),
        // property 'Serial'
        QtMocHelpers::PropertyData<QString>(41, QMetaType::QString, QMC::DefaultPropertyFlags),
        // property 'Vendor'
        QtMocHelpers::PropertyData<QString>(42, QMetaType::QString, QMC::DefaultPropertyFlags),
    };
    QtMocHelpers::UintData qt_enums {
    };
    return QtMocHelpers::metaObjectData<CdDeviceInterface, qt_meta_tag_ZN17CdDeviceInterfaceE_t>(QMC::MetaObjectFlag{}, qt_stringData,
            qt_methods, qt_properties, qt_enums);
}
Q_CONSTINIT const QMetaObject CdDeviceInterface::staticMetaObject = { {
    QMetaObject::SuperData::link<QDBusAbstractInterface::staticMetaObject>(),
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN17CdDeviceInterfaceE_t>.stringdata,
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN17CdDeviceInterfaceE_t>.data,
    qt_static_metacall,
    nullptr,
    qt_staticMetaObjectRelocatingContent<qt_meta_tag_ZN17CdDeviceInterfaceE_t>.metaTypes,
    nullptr
} };

void CdDeviceInterface::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    auto *_t = static_cast<CdDeviceInterface *>(_o);
    if (_c == QMetaObject::InvokeMetaMethod) {
        switch (_id) {
        case 0: _t->Changed(); break;
        case 1: { QDBusPendingReply<> _r = _t->AddProfile((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QDBusObjectPath>>(_a[2])));
            if (_a[0]) *reinterpret_cast<QDBusPendingReply<>*>(_a[0]) = std::move(_r); }  break;
        case 2: { QDBusPendingReply<QDBusObjectPath> _r = _t->GetProfileForQualifiers((*reinterpret_cast<std::add_pointer_t<QStringList>>(_a[1])));
            if (_a[0]) *reinterpret_cast<QDBusPendingReply<QDBusObjectPath>*>(_a[0]) = std::move(_r); }  break;
        case 3: { QDBusPendingReply<QString> _r = _t->GetProfileRelation((*reinterpret_cast<std::add_pointer_t<QDBusObjectPath>>(_a[1])));
            if (_a[0]) *reinterpret_cast<QDBusPendingReply<QString>*>(_a[0]) = std::move(_r); }  break;
        case 4: { QDBusPendingReply<> _r = _t->MakeProfileDefault((*reinterpret_cast<std::add_pointer_t<QDBusObjectPath>>(_a[1])));
            if (_a[0]) *reinterpret_cast<QDBusPendingReply<>*>(_a[0]) = std::move(_r); }  break;
        case 5: { QDBusPendingReply<> _r = _t->ProfilingInhibit();
            if (_a[0]) *reinterpret_cast<QDBusPendingReply<>*>(_a[0]) = std::move(_r); }  break;
        case 6: { QDBusPendingReply<> _r = _t->ProfilingUninhibit();
            if (_a[0]) *reinterpret_cast<QDBusPendingReply<>*>(_a[0]) = std::move(_r); }  break;
        case 7: { QDBusPendingReply<> _r = _t->RemoveProfile((*reinterpret_cast<std::add_pointer_t<QDBusObjectPath>>(_a[1])));
            if (_a[0]) *reinterpret_cast<QDBusPendingReply<>*>(_a[0]) = std::move(_r); }  break;
        case 8: { QDBusPendingReply<> _r = _t->SetEnabled((*reinterpret_cast<std::add_pointer_t<bool>>(_a[1])));
            if (_a[0]) *reinterpret_cast<QDBusPendingReply<>*>(_a[0]) = std::move(_r); }  break;
        case 9: { QDBusPendingReply<> _r = _t->SetProperty((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QString>>(_a[2])));
            if (_a[0]) *reinterpret_cast<QDBusPendingReply<>*>(_a[0]) = std::move(_r); }  break;
        default: ;
        }
    }
    if (_c == QMetaObject::IndexOfMethod) {
        if (QtMocHelpers::indexOfMethod<void (CdDeviceInterface::*)()>(_a, &CdDeviceInterface::Changed, 0))
            return;
    }
    if (_c == QMetaObject::RegisterPropertyMetaType) {
        switch (_id) {
        default: *reinterpret_cast<int*>(_a[0]) = -1; break;
        case 7:
            *reinterpret_cast<int*>(_a[0]) = qRegisterMetaType< CdStringMap >(); break;
        }
    }
    if (_c == QMetaObject::ReadProperty) {
        void *_v = _a[0];
        switch (_id) {
        case 0: *reinterpret_cast<QString*>(_v) = _t->colorspace(); break;
        case 1: *reinterpret_cast<qulonglong*>(_v) = _t->created(); break;
        case 2: *reinterpret_cast<QString*>(_v) = _t->deviceId(); break;
        case 3: *reinterpret_cast<bool*>(_v) = _t->embedded(); break;
        case 4: *reinterpret_cast<bool*>(_v) = _t->enabled(); break;
        case 5: *reinterpret_cast<QString*>(_v) = _t->format(); break;
        case 6: *reinterpret_cast<QString*>(_v) = _t->kind(); break;
        case 7: *reinterpret_cast<CdStringMap*>(_v) = _t->metadata(); break;
        case 8: *reinterpret_cast<QString*>(_v) = _t->mode(); break;
        case 9: *reinterpret_cast<QString*>(_v) = _t->model(); break;
        case 10: *reinterpret_cast<qulonglong*>(_v) = _t->modified(); break;
        case 11: *reinterpret_cast<uint*>(_v) = _t->owner(); break;
        case 12: *reinterpret_cast<QList<QDBusObjectPath>*>(_v) = _t->profiles(); break;
        case 13: *reinterpret_cast<QStringList*>(_v) = _t->profilingInhibitors(); break;
        case 14: *reinterpret_cast<QString*>(_v) = _t->scope(); break;
        case 15: *reinterpret_cast<QString*>(_v) = _t->seat(); break;
        case 16: *reinterpret_cast<QString*>(_v) = _t->serial(); break;
        case 17: *reinterpret_cast<QString*>(_v) = _t->vendor(); break;
        default: break;
        }
    }
}

const QMetaObject *CdDeviceInterface::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *CdDeviceInterface::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_staticMetaObjectStaticContent<qt_meta_tag_ZN17CdDeviceInterfaceE_t>.strings))
        return static_cast<void*>(this);
    return QDBusAbstractInterface::qt_metacast(_clname);
}

int CdDeviceInterface::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = QDBusAbstractInterface::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 10)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 10;
    }
    if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 10)
            *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType();
        _id -= 10;
    }
    if (_c == QMetaObject::ReadProperty || _c == QMetaObject::WriteProperty
            || _c == QMetaObject::ResetProperty || _c == QMetaObject::BindableProperty
            || _c == QMetaObject::RegisterPropertyMetaType) {
        qt_static_metacall(this, _c, _id, _a);
        _id -= 18;
    }
    return _id;
}

// SIGNAL 0
void CdDeviceInterface::Changed()
{
    QMetaObject::activate(this, &staticMetaObject, 0, nullptr);
}
QT_WARNING_POP
