/****************************************************************************
** Meta object code from reading C++ file 'CdProfileInterface.h'
**
** Created by: The Qt Meta Object Compiler version 69 (Qt 6.11.1)
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#include "CdProfileInterface.h"
#include <QtCore/qmetatype.h>

#include <QtCore/qtmochelpers.h>

#include <memory>


#include <QtCore/qxptype_traits.h>
#if !defined(Q_MOC_OUTPUT_REVISION)
#error "The header file 'CdProfileInterface.h' doesn't include <QObject>."
#elif Q_MOC_OUTPUT_REVISION != 69
#error "This file was generated using the moc from 6.11.1. It"
#error "cannot be used with the include files from this version of Qt."
#error "(The moc has changed too much.)"
#endif

#ifndef Q_CONSTINIT
#define Q_CONSTINIT
#endif

QT_WARNING_PUSH
QT_WARNING_DISABLE_DEPRECATED
QT_WARNING_DISABLE_GCC("-Wuseless-cast")
namespace {
struct qt_meta_tag_ZN18CdProfileInterfaceE_t {};
} // unnamed namespace

template <> constexpr inline auto CdProfileInterface::qt_create_metaobjectdata<qt_meta_tag_ZN18CdProfileInterfaceE_t>()
{
    namespace QMC = QtMocConstants;
    QtMocHelpers::StringRefStorage qt_stringData {
        "CdProfileInterface",
        "Changed",
        "",
        "InstallSystemWide",
        "QDBusPendingReply<>",
        "SetProperty",
        "property_name",
        "property_value",
        "Colorspace",
        "Created",
        "Filename",
        "Format",
        "HasVcgt",
        "IsSystemWide",
        "Kind",
        "Metadata",
        "CdStringMap",
        "Owner",
        "ProfileId",
        "Qualifier",
        "Scope",
        "Title",
        "Warnings"
    };

    QtMocHelpers::UintData qt_methods {
        // Signal 'Changed'
        QtMocHelpers::SignalData<void()>(1, 2, QMC::AccessPublic, QMetaType::Void),
        // Slot 'InstallSystemWide'
        QtMocHelpers::SlotData<QDBusPendingReply<>()>(3, 2, QMC::AccessPublic, 0x80000000 | 4),
        // Slot 'SetProperty'
        QtMocHelpers::SlotData<QDBusPendingReply<>(const QString &, const QString &)>(5, 2, QMC::AccessPublic, 0x80000000 | 4, {{
            { QMetaType::QString, 6 }, { QMetaType::QString, 7 },
        }}),
    };
    QtMocHelpers::UintData qt_properties {
        // property 'Colorspace'
        QtMocHelpers::PropertyData<QString>(8, QMetaType::QString, QMC::DefaultPropertyFlags),
        // property 'Created'
        QtMocHelpers::PropertyData<qlonglong>(9, QMetaType::LongLong, QMC::DefaultPropertyFlags),
        // property 'Filename'
        QtMocHelpers::PropertyData<QString>(10, QMetaType::QString, QMC::DefaultPropertyFlags),
        // property 'Format'
        QtMocHelpers::PropertyData<QString>(11, QMetaType::QString, QMC::DefaultPropertyFlags),
        // property 'HasVcgt'
        QtMocHelpers::PropertyData<bool>(12, QMetaType::Bool, QMC::DefaultPropertyFlags),
        // property 'IsSystemWide'
        QtMocHelpers::PropertyData<bool>(13, QMetaType::Bool, QMC::DefaultPropertyFlags),
        // property 'Kind'
        QtMocHelpers::PropertyData<QString>(14, QMetaType::QString, QMC::DefaultPropertyFlags),
        // property 'Metadata'
        QtMocHelpers::PropertyData<CdStringMap>(15, 0x80000000 | 16, QMC::DefaultPropertyFlags | QMC::EnumOrFlag),
        // property 'Owner'
        QtMocHelpers::PropertyData<uint>(17, QMetaType::UInt, QMC::DefaultPropertyFlags),
        // property 'ProfileId'
        QtMocHelpers::PropertyData<QString>(18, QMetaType::QString, QMC::DefaultPropertyFlags),
        // property 'Qualifier'
        QtMocHelpers::PropertyData<QString>(19, QMetaType::QString, QMC::DefaultPropertyFlags),
        // property 'Scope'
        QtMocHelpers::PropertyData<QString>(20, QMetaType::QString, QMC::DefaultPropertyFlags),
        // property 'Title'
        QtMocHelpers::PropertyData<QString>(21, QMetaType::QString, QMC::DefaultPropertyFlags),
        // property 'Warnings'
        QtMocHelpers::PropertyData<QStringList>(22, QMetaType::QStringList, QMC::DefaultPropertyFlags),
    };
    QtMocHelpers::UintData qt_enums {
    };
    return QtMocHelpers::metaObjectData<CdProfileInterface, qt_meta_tag_ZN18CdProfileInterfaceE_t>(QMC::MetaObjectFlag{}, qt_stringData,
            qt_methods, qt_properties, qt_enums);
}
Q_CONSTINIT const QMetaObject CdProfileInterface::staticMetaObject = { {
    QMetaObject::SuperData::link<QDBusAbstractInterface::staticMetaObject>(),
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN18CdProfileInterfaceE_t>.stringdata,
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN18CdProfileInterfaceE_t>.data,
    qt_static_metacall,
    nullptr,
    qt_staticMetaObjectRelocatingContent<qt_meta_tag_ZN18CdProfileInterfaceE_t>.metaTypes,
    nullptr
} };

void CdProfileInterface::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    auto *_t = static_cast<CdProfileInterface *>(_o);
    if (_c == QMetaObject::InvokeMetaMethod) {
        switch (_id) {
        case 0: _t->Changed(); break;
        case 1: { QDBusPendingReply<> _r = _t->InstallSystemWide();
            if (_a[0]) *reinterpret_cast<QDBusPendingReply<>*>(_a[0]) = std::move(_r); }  break;
        case 2: { QDBusPendingReply<> _r = _t->SetProperty((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QString>>(_a[2])));
            if (_a[0]) *reinterpret_cast<QDBusPendingReply<>*>(_a[0]) = std::move(_r); }  break;
        default: ;
        }
    }
    if (_c == QMetaObject::IndexOfMethod) {
        if (QtMocHelpers::indexOfMethod<void (CdProfileInterface::*)()>(_a, &CdProfileInterface::Changed, 0))
            return;
    }
    if (_c == QMetaObject::RegisterPropertyMetaType) {
        switch (_id) {
        default: *reinterpret_cast<int*>(_a[0]) = -1; break;
        case 7:
            *reinterpret_cast<int*>(_a[0]) = qRegisterMetaType< CdStringMap >(); break;
        }
    }
    if (_c == QMetaObject::ReadProperty) {
        void *_v = _a[0];
        switch (_id) {
        case 0: *reinterpret_cast<QString*>(_v) = _t->colorspace(); break;
        case 1: *reinterpret_cast<qlonglong*>(_v) = _t->created(); break;
        case 2: *reinterpret_cast<QString*>(_v) = _t->filename(); break;
        case 3: *reinterpret_cast<QString*>(_v) = _t->format(); break;
        case 4: *reinterpret_cast<bool*>(_v) = _t->hasVcgt(); break;
        case 5: *reinterpret_cast<bool*>(_v) = _t->isSystemWide(); break;
        case 6: *reinterpret_cast<QString*>(_v) = _t->kind(); break;
        case 7: *reinterpret_cast<CdStringMap*>(_v) = _t->metadata(); break;
        case 8: *reinterpret_cast<uint*>(_v) = _t->owner(); break;
        case 9: *reinterpret_cast<QString*>(_v) = _t->profileId(); break;
        case 10: *reinterpret_cast<QString*>(_v) = _t->qualifier(); break;
        case 11: *reinterpret_cast<QString*>(_v) = _t->scope(); break;
        case 12: *reinterpret_cast<QString*>(_v) = _t->title(); break;
        case 13: *reinterpret_cast<QStringList*>(_v) = _t->warnings(); break;
        default: break;
        }
    }
}

const QMetaObject *CdProfileInterface::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *CdProfileInterface::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_staticMetaObjectStaticContent<qt_meta_tag_ZN18CdProfileInterfaceE_t>.strings))
        return static_cast<void*>(this);
    return QDBusAbstractInterface::qt_metacast(_clname);
}

int CdProfileInterface::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = QDBusAbstractInterface::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 3)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 3;
    }
    if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 3)
            *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType();
        _id -= 3;
    }
    if (_c == QMetaObject::ReadProperty || _c == QMetaObject::WriteProperty
            || _c == QMetaObject::ResetProperty || _c == QMetaObject::BindableProperty
            || _c == QMetaObject::RegisterPropertyMetaType) {
        qt_static_metacall(this, _c, _id, _a);
        _id -= 14;
    }
    return _id;
}

// SIGNAL 0
void CdProfileInterface::Changed()
{
    QMetaObject::activate(this, &staticMetaObject, 0, nullptr);
}
QT_WARNING_POP
