/*
 * This file was generated by qdbusxml2cpp version 0.8
 * Source file was org.freedesktop.ColorManager.Device.xml
 *
 * qdbusxml2cpp is Copyright (C) The Qt Company Ltd. and other contributors.
 *
 * This is an auto-generated file.
 * Do not edit! All changes made to it will be lost.
 */

#ifndef CDDEVICEINTERFACE_H
#define CDDEVICEINTERFACE_H

#include <QtCore/QObject>
#include <QtCore/QByteArray>
#include <QtCore/QList>
#include <QtCore/QMap>
#include <QtCore/QString>
#include <QtCore/QStringList>
#include <QtCore/QVariant>
#include <QtDBus/QtDBus>
#include "dbus-types.h"

/*
 * Proxy class for interface org.freedesktop.ColorManager.Device
 */
class CdDeviceInterface: public QDBusAbstractInterface
{
    Q_OBJECT
public:
    static inline const char *staticInterfaceName()
    { return "org.freedesktop.ColorManager.Device"; }

public:
    CdDeviceInterface(const QString &service, const QString &path, const QDBusConnection &connection, QObject *parent = nullptr);

    ~CdDeviceInterface();

    Q_PROPERTY(QString Colorspace READ colorspace)
    inline QString colorspace() const
    { return qvariant_cast< QString >(property("Colorspace")); }

    Q_PROPERTY(qulonglong Created READ created)
    inline qulonglong created() const
    { return qvariant_cast< qulonglong >(property("Created")); }

    Q_PROPERTY(QString DeviceId READ deviceId)
    inline QString deviceId() const
    { return qvariant_cast< QString >(property("DeviceId")); }

    Q_PROPERTY(bool Embedded READ embedded)
    inline bool embedded() const
    { return qvariant_cast< bool >(property("Embedded")); }

    Q_PROPERTY(bool Enabled READ enabled)
    inline bool enabled() const
    { return qvariant_cast< bool >(property("Enabled")); }

    Q_PROPERTY(QString Format READ format)
    inline QString format() const
    { return qvariant_cast< QString >(property("Format")); }

    Q_PROPERTY(QString Kind READ kind)
    inline QString kind() const
    { return qvariant_cast< QString >(property("Kind")); }

    Q_PROPERTY(CdStringMap Metadata READ metadata)
    inline CdStringMap metadata() const
    { return qvariant_cast< CdStringMap >(property("Metadata")); }

    Q_PROPERTY(QString Mode READ mode)
    inline QString mode() const
    { return qvariant_cast< QString >(property("Mode")); }

    Q_PROPERTY(QString Model READ model)
    inline QString model() const
    { return qvariant_cast< QString >(property("Model")); }

    Q_PROPERTY(qulonglong Modified READ modified)
    inline qulonglong modified() const
    { return qvariant_cast< qulonglong >(property("Modified")); }

    Q_PROPERTY(uint Owner READ owner)
    inline uint owner() const
    { return qvariant_cast< uint >(property("Owner")); }

    Q_PROPERTY(QList<QDBusObjectPath> Profiles READ profiles)
    inline QList<QDBusObjectPath> profiles() const
    { return qvariant_cast< QList<QDBusObjectPath> >(property("Profiles")); }

    Q_PROPERTY(QStringList ProfilingInhibitors READ profilingInhibitors)
    inline QStringList profilingInhibitors() const
    { return qvariant_cast< QStringList >(property("ProfilingInhibitors")); }

    Q_PROPERTY(QString Scope READ scope)
    inline QString scope() const
    { return qvariant_cast< QString >(property("Scope")); }

    Q_PROPERTY(QString Seat READ seat)
    inline QString seat() const
    { return qvariant_cast< QString >(property("Seat")); }

    Q_PROPERTY(QString Serial READ serial)
    inline QString serial() const
    { return qvariant_cast< QString >(property("Serial")); }

    Q_PROPERTY(QString Vendor READ vendor)
    inline QString vendor() const
    { return qvariant_cast< QString >(property("Vendor")); }

public Q_SLOTS: // METHODS
    inline QDBusPendingReply<> AddProfile(const QString &relation, const QDBusObjectPath &object_path)
    {
        QList<QVariant> argumentList;
        argumentList << QVariant::fromValue(relation) << QVariant::fromValue(object_path);
        return asyncCallWithArgumentList(QStringLiteral("AddProfile"), argumentList);
    }

    inline QDBusPendingReply<QDBusObjectPath> GetProfileForQualifiers(const QStringList &qualifiers)
    {
        QList<QVariant> argumentList;
        argumentList << QVariant::fromValue(qualifiers);
        return asyncCallWithArgumentList(QStringLiteral("GetProfileForQualifiers"), argumentList);
    }

    inline QDBusPendingReply<QString> GetProfileRelation(const QDBusObjectPath &object_path)
    {
        QList<QVariant> argumentList;
        argumentList << QVariant::fromValue(object_path);
        return asyncCallWithArgumentList(QStringLiteral("GetProfileRelation"), argumentList);
    }

    inline QDBusPendingReply<> MakeProfileDefault(const QDBusObjectPath &profile_path)
    {
        QList<QVariant> argumentList;
        argumentList << QVariant::fromValue(profile_path);
        return asyncCallWithArgumentList(QStringLiteral("MakeProfileDefault"), argumentList);
    }

    inline QDBusPendingReply<> ProfilingInhibit()
    {
        QList<QVariant> argumentList;
        return asyncCallWithArgumentList(QStringLiteral("ProfilingInhibit"), argumentList);
    }

    inline QDBusPendingReply<> ProfilingUninhibit()
    {
        QList<QVariant> argumentList;
        return asyncCallWithArgumentList(QStringLiteral("ProfilingUninhibit"), argumentList);
    }

    inline QDBusPendingReply<> RemoveProfile(const QDBusObjectPath &object_path)
    {
        QList<QVariant> argumentList;
        argumentList << QVariant::fromValue(object_path);
        return asyncCallWithArgumentList(QStringLiteral("RemoveProfile"), argumentList);
    }

    inline QDBusPendingReply<> SetEnabled(bool enabled)
    {
        QList<QVariant> argumentList;
        argumentList << QVariant::fromValue(enabled);
        return asyncCallWithArgumentList(QStringLiteral("SetEnabled"), argumentList);
    }

    inline QDBusPendingReply<> SetProperty(const QString &property_name, const QString &property_value)
    {
        QList<QVariant> argumentList;
        argumentList << QVariant::fromValue(property_name) << QVariant::fromValue(property_value);
        return asyncCallWithArgumentList(QStringLiteral("SetProperty"), argumentList);
    }

Q_SIGNALS: // SIGNALS
    void Changed();
};

#endif
