/*
 * This file was generated by qdbusxml2cpp version 0.8
 * Source file was org.freedesktop.ColorManager.Profile.xml
 *
 * qdbusxml2cpp is Copyright (C) The Qt Company Ltd. and other contributors.
 *
 * This is an auto-generated file.
 * Do not edit! All changes made to it will be lost.
 */

#ifndef CDPROFILEINTERFACE_H
#define CDPROFILEINTERFACE_H

#include <QtCore/QObject>
#include <QtCore/QByteArray>
#include <QtCore/QList>
#include <QtCore/QMap>
#include <QtCore/QString>
#include <QtCore/QStringList>
#include <QtCore/QVariant>
#include <QtDBus/QtDBus>
#include "dbus-types.h"

/*
 * Proxy class for interface org.freedesktop.ColorManager.Profile
 */
class CdProfileInterface: public QDBusAbstractInterface
{
    Q_OBJECT
public:
    static inline const char *staticInterfaceName()
    { return "org.freedesktop.ColorManager.Profile"; }

public:
    CdProfileInterface(const QString &service, const QString &path, const QDBusConnection &connection, QObject *parent = nullptr);

    ~CdProfileInterface();

    Q_PROPERTY(QString Colorspace READ colorspace)
    inline QString colorspace() const
    { return qvariant_cast< QString >(property("Colorspace")); }

    Q_PROPERTY(qlonglong Created READ created)
    inline qlonglong created() const
    { return qvariant_cast< qlonglong >(property("Created")); }

    Q_PROPERTY(QString Filename READ filename)
    inline QString filename() const
    { return qvariant_cast< QString >(property("Filename")); }

    Q_PROPERTY(QString Format READ format)
    inline QString format() const
    { return qvariant_cast< QString >(property("Format")); }

    Q_PROPERTY(bool HasVcgt READ hasVcgt)
    inline bool hasVcgt() const
    { return qvariant_cast< bool >(property("HasVcgt")); }

    Q_PROPERTY(bool IsSystemWide READ isSystemWide)
    inline bool isSystemWide() const
    { return qvariant_cast< bool >(property("IsSystemWide")); }

    Q_PROPERTY(QString Kind READ kind)
    inline QString kind() const
    { return qvariant_cast< QString >(property("Kind")); }

    Q_PROPERTY(CdStringMap Metadata READ metadata)
    inline CdStringMap metadata() const
    { return qvariant_cast< CdStringMap >(property("Metadata")); }

    Q_PROPERTY(uint Owner READ owner)
    inline uint owner() const
    { return qvariant_cast< uint >(property("Owner")); }

    Q_PROPERTY(QString ProfileId READ profileId)
    inline QString profileId() const
    { return qvariant_cast< QString >(property("ProfileId")); }

    Q_PROPERTY(QString Qualifier READ qualifier)
    inline QString qualifier() const
    { return qvariant_cast< QString >(property("Qualifier")); }

    Q_PROPERTY(QString Scope READ scope)
    inline QString scope() const
    { return qvariant_cast< QString >(property("Scope")); }

    Q_PROPERTY(QString Title READ title)
    inline QString title() const
    { return qvariant_cast< QString >(property("Title")); }

    Q_PROPERTY(QStringList Warnings READ warnings)
    inline QStringList warnings() const
    { return qvariant_cast< QStringList >(property("Warnings")); }

public Q_SLOTS: // METHODS
    inline QDBusPendingReply<> InstallSystemWide()
    {
        QList<QVariant> argumentList;
        return asyncCallWithArgumentList(QStringLiteral("InstallSystemWide"), argumentList);
    }

    inline QDBusPendingReply<> SetProperty(const QString &property_name, const QString &property_value)
    {
        QList<QVariant> argumentList;
        argumentList << QVariant::fromValue(property_name) << QVariant::fromValue(property_value);
        return asyncCallWithArgumentList(QStringLiteral("SetProperty"), argumentList);
    }

Q_SIGNALS: // SIGNALS
    void Changed();
};

#endif
