/****************************************************************************
** Meta object code from reading C++ file 'DeviceDescription.h'
**
** Created by: The Qt Meta Object Compiler version 69 (Qt 6.11.1)
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#include "../../../../colord-kde-26.04.3/colord-kcm/DeviceDescription.h"
#include <QtCore/qmetatype.h>

#include <QtCore/qtmochelpers.h>

#include <memory>


#include <QtCore/qxptype_traits.h>
#if !defined(Q_MOC_OUTPUT_REVISION)
#error "The header file 'DeviceDescription.h' doesn't include <QObject>."
#elif Q_MOC_OUTPUT_REVISION != 69
#error "This file was generated using the moc from 6.11.1. It"
#error "cannot be used with the include files from this version of Qt."
#error "(The moc has changed too much.)"
#endif

#ifndef Q_CONSTINIT
#define Q_CONSTINIT
#endif

QT_WARNING_PUSH
QT_WARNING_DISABLE_DEPRECATED
QT_WARNING_DISABLE_GCC("-Wuseless-cast")
namespace {
struct qt_meta_tag_ZN17DeviceDescriptionE_t {};
} // unnamed namespace

template <> constexpr inline auto DeviceDescription::qt_create_metaobjectdata<qt_meta_tag_ZN17DeviceDescriptionE_t>()
{
    namespace QMC = QtMocConstants;
    QtMocHelpers::StringRefStorage qt_stringData {
        "DeviceDescription",
        "isDeviceChanged",
        "",
        "dataChanged",
        "calibrateChanged",
        "calibrateMessageChanged",
        "gotSensors",
        "QDBusPendingCallWatcher*",
        "call",
        "sensorAddedUpdateCalibrateButton",
        "QDBusObjectPath",
        "sensorPath",
        "sensorRemovedUpdateCalibrateButton",
        "setDevice",
        "objectPath",
        "colorSpace",
        "deviceTitle",
        "deviceID",
        "deviceScope",
        "deviceKind",
        "currentProfileTitle",
        "calibrateTipMessage"
    };

    QtMocHelpers::UintData qt_methods {
        // Signal 'isDeviceChanged'
        QtMocHelpers::SignalData<void()>(1, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'dataChanged'
        QtMocHelpers::SignalData<void()>(3, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'calibrateChanged'
        QtMocHelpers::SignalData<void()>(4, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'calibrateMessageChanged'
        QtMocHelpers::SignalData<void()>(5, 2, QMC::AccessPublic, QMetaType::Void),
        // Slot 'gotSensors'
        QtMocHelpers::SlotData<void(QDBusPendingCallWatcher *)>(6, 2, QMC::AccessPrivate, QMetaType::Void, {{
            { 0x80000000 | 7, 8 },
        }}),
        // Slot 'sensorAddedUpdateCalibrateButton'
        QtMocHelpers::SlotData<void(const QDBusObjectPath &)>(9, 2, QMC::AccessPrivate, QMetaType::Void, {{
            { 0x80000000 | 10, 11 },
        }}),
        // Slot 'sensorRemovedUpdateCalibrateButton'
        QtMocHelpers::SlotData<void(const QDBusObjectPath &)>(12, 2, QMC::AccessPrivate, QMetaType::Void, {{
            { 0x80000000 | 10, 11 },
        }}),
        // Method 'setDevice'
        QtMocHelpers::MethodData<void(const QDBusObjectPath &)>(13, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 10, 14 },
        }}),
    };
    QtMocHelpers::UintData qt_properties {
        // property 'colorSpace'
        QtMocHelpers::PropertyData<QString>(15, QMetaType::QString, QMC::DefaultPropertyFlags | QMC::Writable, 1),
        // property 'deviceTitle'
        QtMocHelpers::PropertyData<QString>(16, QMetaType::QString, QMC::DefaultPropertyFlags | QMC::Writable, 1),
        // property 'deviceID'
        QtMocHelpers::PropertyData<QString>(17, QMetaType::QString, QMC::DefaultPropertyFlags | QMC::Writable, 1),
        // property 'deviceScope'
        QtMocHelpers::PropertyData<QString>(18, QMetaType::QString, QMC::DefaultPropertyFlags | QMC::Writable, 1),
        // property 'deviceKind'
        QtMocHelpers::PropertyData<QString>(19, QMetaType::QString, QMC::DefaultPropertyFlags | QMC::Writable, 1),
        // property 'currentProfileTitle'
        QtMocHelpers::PropertyData<QString>(20, QMetaType::QString, QMC::DefaultPropertyFlags | QMC::Writable, 1),
        // property 'calibrateTipMessage'
        QtMocHelpers::PropertyData<QString>(21, QMetaType::QString, QMC::DefaultPropertyFlags | QMC::Writable, 3),
    };
    QtMocHelpers::UintData qt_enums {
    };
    return QtMocHelpers::metaObjectData<DeviceDescription, qt_meta_tag_ZN17DeviceDescriptionE_t>(QMC::MetaObjectFlag{}, qt_stringData,
            qt_methods, qt_properties, qt_enums);
}
Q_CONSTINIT const QMetaObject DeviceDescription::staticMetaObject = { {
    QMetaObject::SuperData::link<QObject::staticMetaObject>(),
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN17DeviceDescriptionE_t>.stringdata,
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN17DeviceDescriptionE_t>.data,
    qt_static_metacall,
    nullptr,
    qt_staticMetaObjectRelocatingContent<qt_meta_tag_ZN17DeviceDescriptionE_t>.metaTypes,
    nullptr
} };

void DeviceDescription::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    auto *_t = static_cast<DeviceDescription *>(_o);
    if (_c == QMetaObject::InvokeMetaMethod) {
        switch (_id) {
        case 0: _t->isDeviceChanged(); break;
        case 1: _t->dataChanged(); break;
        case 2: _t->calibrateChanged(); break;
        case 3: _t->calibrateMessageChanged(); break;
        case 4: _t->gotSensors((*reinterpret_cast<std::add_pointer_t<QDBusPendingCallWatcher*>>(_a[1]))); break;
        case 5: _t->sensorAddedUpdateCalibrateButton((*reinterpret_cast<std::add_pointer_t<QDBusObjectPath>>(_a[1]))); break;
        case 6: _t->sensorRemovedUpdateCalibrateButton((*reinterpret_cast<std::add_pointer_t<QDBusObjectPath>>(_a[1]))); break;
        case 7: _t->setDevice((*reinterpret_cast<std::add_pointer_t<QDBusObjectPath>>(_a[1]))); break;
        default: ;
        }
    }
    if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        switch (_id) {
        default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
        case 4:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
            case 0:
                *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType::fromType< QDBusPendingCallWatcher* >(); break;
            }
            break;
        case 5:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
            case 0:
                *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType::fromType< QDBusObjectPath >(); break;
            }
            break;
        case 6:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
            case 0:
                *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType::fromType< QDBusObjectPath >(); break;
            }
            break;
        case 7:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
            case 0:
                *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType::fromType< QDBusObjectPath >(); break;
            }
            break;
        }
    }
    if (_c == QMetaObject::IndexOfMethod) {
        if (QtMocHelpers::indexOfMethod<void (DeviceDescription::*)()>(_a, &DeviceDescription::isDeviceChanged, 0))
            return;
        if (QtMocHelpers::indexOfMethod<void (DeviceDescription::*)()>(_a, &DeviceDescription::dataChanged, 1))
            return;
        if (QtMocHelpers::indexOfMethod<void (DeviceDescription::*)()>(_a, &DeviceDescription::calibrateChanged, 2))
            return;
        if (QtMocHelpers::indexOfMethod<void (DeviceDescription::*)()>(_a, &DeviceDescription::calibrateMessageChanged, 3))
            return;
    }
    if (_c == QMetaObject::ReadProperty) {
        void *_v = _a[0];
        switch (_id) {
        case 0: *reinterpret_cast<QString*>(_v) = _t->m_colorSpace; break;
        case 1: *reinterpret_cast<QString*>(_v) = _t->m_deviceTitle; break;
        case 2: *reinterpret_cast<QString*>(_v) = _t->m_currentDeviceID; break;
        case 3: *reinterpret_cast<QString*>(_v) = _t->m_deviceScope; break;
        case 4: *reinterpret_cast<QString*>(_v) = _t->m_currentDeviceKind; break;
        case 5: *reinterpret_cast<QString*>(_v) = _t->m_currentProfileTitle; break;
        case 6: *reinterpret_cast<QString*>(_v) = _t->m_calibrateMsg; break;
        default: break;
        }
    }
    if (_c == QMetaObject::WriteProperty) {
        void *_v = _a[0];
        switch (_id) {
        case 0:
            if (QtMocHelpers::setProperty(_t->m_colorSpace, *reinterpret_cast<QString*>(_v)))
                Q_EMIT _t->dataChanged();
            break;
        case 1:
            if (QtMocHelpers::setProperty(_t->m_deviceTitle, *reinterpret_cast<QString*>(_v)))
                Q_EMIT _t->dataChanged();
            break;
        case 2:
            if (QtMocHelpers::setProperty(_t->m_currentDeviceID, *reinterpret_cast<QString*>(_v)))
                Q_EMIT _t->dataChanged();
            break;
        case 3:
            if (QtMocHelpers::setProperty(_t->m_deviceScope, *reinterpret_cast<QString*>(_v)))
                Q_EMIT _t->dataChanged();
            break;
        case 4:
            if (QtMocHelpers::setProperty(_t->m_currentDeviceKind, *reinterpret_cast<QString*>(_v)))
                Q_EMIT _t->dataChanged();
            break;
        case 5:
            if (QtMocHelpers::setProperty(_t->m_currentProfileTitle, *reinterpret_cast<QString*>(_v)))
                Q_EMIT _t->dataChanged();
            break;
        case 6:
            if (QtMocHelpers::setProperty(_t->m_calibrateMsg, *reinterpret_cast<QString*>(_v)))
                Q_EMIT _t->calibrateMessageChanged();
            break;
        default: break;
        }
    }
}

const QMetaObject *DeviceDescription::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *DeviceDescription::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_staticMetaObjectStaticContent<qt_meta_tag_ZN17DeviceDescriptionE_t>.strings))
        return static_cast<void*>(this);
    return QObject::qt_metacast(_clname);
}

int DeviceDescription::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = QObject::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 8)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 8;
    }
    if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 8)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 8;
    }
    if (_c == QMetaObject::ReadProperty || _c == QMetaObject::WriteProperty
            || _c == QMetaObject::ResetProperty || _c == QMetaObject::BindableProperty
            || _c == QMetaObject::RegisterPropertyMetaType) {
        qt_static_metacall(this, _c, _id, _a);
        _id -= 7;
    }
    return _id;
}

// SIGNAL 0
void DeviceDescription::isDeviceChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 0, nullptr);
}

// SIGNAL 1
void DeviceDescription::dataChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 1, nullptr);
}

// SIGNAL 2
void DeviceDescription::calibrateChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 2, nullptr);
}

// SIGNAL 3
void DeviceDescription::calibrateMessageChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 3, nullptr);
}
QT_WARNING_POP
