/****************************************************************************
** Meta object code from reading C++ file 'ProfileDescription.h'
**
** Created by: The Qt Meta Object Compiler version 69 (Qt 6.11.1)
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#include "../../../../colord-kde-26.04.3/colord-kcm/ProfileDescription.h"
#include <QtCore/qmetatype.h>

#include <QtCore/qtmochelpers.h>

#include <memory>


#include <QtCore/qxptype_traits.h>
#if !defined(Q_MOC_OUTPUT_REVISION)
#error "The header file 'ProfileDescription.h' doesn't include <QObject>."
#elif Q_MOC_OUTPUT_REVISION != 69
#error "This file was generated using the moc from 6.11.1. It"
#error "cannot be used with the include files from this version of Qt."
#error "(The moc has changed too much.)"
#endif

#ifndef Q_CONSTINIT
#define Q_CONSTINIT
#endif

QT_WARNING_PUSH
QT_WARNING_DISABLE_DEPRECATED
QT_WARNING_DISABLE_GCC("-Wuseless-cast")
namespace {
struct qt_meta_tag_ZN18ProfileDescriptionE_t {};
} // unnamed namespace

template <> constexpr inline auto ProfileDescription::qt_create_metaobjectdata<qt_meta_tag_ZN18ProfileDescriptionE_t>()
{
    namespace QMC = QtMocConstants;
    QtMocHelpers::StringRefStorage qt_stringData {
        "ProfileDescription",
        "dataChanged",
        "",
        "setProfile",
        "QDBusObjectPath",
        "objectPath",
        "canRemoveProfile",
        "installSystemWide",
        "metaDataModel",
        "ProfileMetaDataModel*",
        "namedColorsModel",
        "ProfileNamedColorsModel*",
        "path",
        "kind",
        "colorSpace",
        "version",
        "createdTime",
        "license",
        "manufacturer",
        "model",
        "size",
        "filename",
        "whitePoint",
        "canRemove",
        "hasDisplayCorrection"
    };

    QtMocHelpers::UintData qt_methods {
        // Signal 'dataChanged'
        QtMocHelpers::SignalData<void()>(1, 2, QMC::AccessPublic, QMetaType::Void),
        // Method 'setProfile'
        QtMocHelpers::MethodData<void(const QDBusObjectPath &, bool)>(3, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 4, 5 }, { QMetaType::Bool, 6 },
        }}),
        // Method 'installSystemWide'
        QtMocHelpers::MethodData<void()>(7, 2, QMC::AccessPublic, QMetaType::Void),
    };
    QtMocHelpers::UintData qt_properties {
        // property 'metaDataModel'
        QtMocHelpers::PropertyData<ProfileMetaDataModel*>(8, 0x80000000 | 9, QMC::DefaultPropertyFlags | QMC::EnumOrFlag | QMC::Constant),
        // property 'namedColorsModel'
        QtMocHelpers::PropertyData<ProfileNamedColorsModel*>(10, 0x80000000 | 11, QMC::DefaultPropertyFlags | QMC::EnumOrFlag | QMC::Constant),
        // property 'path'
        QtMocHelpers::PropertyData<QDBusObjectPath>(12, 0x80000000 | 4, QMC::DefaultPropertyFlags | QMC::Writable | QMC::EnumOrFlag, 0),
        // property 'kind'
        QtMocHelpers::PropertyData<QString>(13, QMetaType::QString, QMC::DefaultPropertyFlags | QMC::Writable, 0),
        // property 'colorSpace'
        QtMocHelpers::PropertyData<QString>(14, QMetaType::QString, QMC::DefaultPropertyFlags | QMC::Writable, 0),
        // property 'version'
        QtMocHelpers::PropertyData<QString>(15, QMetaType::QString, QMC::DefaultPropertyFlags | QMC::Writable, 0),
        // property 'createdTime'
        QtMocHelpers::PropertyData<QString>(16, QMetaType::QString, QMC::DefaultPropertyFlags | QMC::Writable, 0),
        // property 'license'
        QtMocHelpers::PropertyData<QString>(17, QMetaType::QString, QMC::DefaultPropertyFlags | QMC::Writable, 0),
        // property 'manufacturer'
        QtMocHelpers::PropertyData<QString>(18, QMetaType::QString, QMC::DefaultPropertyFlags | QMC::Writable, 0),
        // property 'model'
        QtMocHelpers::PropertyData<QString>(19, QMetaType::QString, QMC::DefaultPropertyFlags | QMC::Writable, 0),
        // property 'size'
        QtMocHelpers::PropertyData<QString>(20, QMetaType::QString, QMC::DefaultPropertyFlags | QMC::Writable, 0),
        // property 'filename'
        QtMocHelpers::PropertyData<QString>(21, QMetaType::QString, QMC::DefaultPropertyFlags | QMC::Writable, 0),
        // property 'whitePoint'
        QtMocHelpers::PropertyData<QString>(22, QMetaType::QString, QMC::DefaultPropertyFlags | QMC::Writable, 0),
        // property 'canRemove'
        QtMocHelpers::PropertyData<bool>(23, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Writable, 0),
        // property 'hasDisplayCorrection'
        QtMocHelpers::PropertyData<bool>(24, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Writable, 0),
    };
    QtMocHelpers::UintData qt_enums {
    };
    return QtMocHelpers::metaObjectData<ProfileDescription, qt_meta_tag_ZN18ProfileDescriptionE_t>(QMC::MetaObjectFlag{}, qt_stringData,
            qt_methods, qt_properties, qt_enums);
}
Q_CONSTINIT const QMetaObject ProfileDescription::staticMetaObject = { {
    QMetaObject::SuperData::link<QObject::staticMetaObject>(),
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN18ProfileDescriptionE_t>.stringdata,
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN18ProfileDescriptionE_t>.data,
    qt_static_metacall,
    nullptr,
    qt_staticMetaObjectRelocatingContent<qt_meta_tag_ZN18ProfileDescriptionE_t>.metaTypes,
    nullptr
} };

void ProfileDescription::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    auto *_t = static_cast<ProfileDescription *>(_o);
    if (_c == QMetaObject::InvokeMetaMethod) {
        switch (_id) {
        case 0: _t->dataChanged(); break;
        case 1: _t->setProfile((*reinterpret_cast<std::add_pointer_t<QDBusObjectPath>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<bool>>(_a[2]))); break;
        case 2: _t->installSystemWide(); break;
        default: ;
        }
    }
    if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        switch (_id) {
        default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
        case 1:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
            case 0:
                *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType::fromType< QDBusObjectPath >(); break;
            }
            break;
        }
    }
    if (_c == QMetaObject::IndexOfMethod) {
        if (QtMocHelpers::indexOfMethod<void (ProfileDescription::*)()>(_a, &ProfileDescription::dataChanged, 0))
            return;
    }
    if (_c == QMetaObject::RegisterPropertyMetaType) {
        switch (_id) {
        default: *reinterpret_cast<int*>(_a[0]) = -1; break;
        case 2:
            *reinterpret_cast<int*>(_a[0]) = qRegisterMetaType< QDBusObjectPath >(); break;
        }
    }
    if (_c == QMetaObject::ReadProperty) {
        void *_v = _a[0];
        switch (_id) {
        case 0: *reinterpret_cast<ProfileMetaDataModel**>(_v) = _t->metaDataModel(); break;
        case 1: *reinterpret_cast<ProfileNamedColorsModel**>(_v) = _t->namedColorsModel(); break;
        case 2: *reinterpret_cast<QDBusObjectPath*>(_v) = _t->m_currentProfilePath; break;
        case 3: *reinterpret_cast<QString*>(_v) = _t->m_profileKind; break;
        case 4: *reinterpret_cast<QString*>(_v) = _t->m_profileColorSpace; break;
        case 5: *reinterpret_cast<QString*>(_v) = _t->m_profileVersion; break;
        case 6: *reinterpret_cast<QString*>(_v) = _t->m_profileCreatedTime; break;
        case 7: *reinterpret_cast<QString*>(_v) = _t->m_profileLicense; break;
        case 8: *reinterpret_cast<QString*>(_v) = _t->m_profileManufacturer; break;
        case 9: *reinterpret_cast<QString*>(_v) = _t->m_profileModel; break;
        case 10: *reinterpret_cast<QString*>(_v) = _t->m_profileSize; break;
        case 11: *reinterpret_cast<QString*>(_v) = _t->m_profileName; break;
        case 12: *reinterpret_cast<QString*>(_v) = _t->m_profileWhitePoint; break;
        case 13: *reinterpret_cast<bool*>(_v) = _t->m_canRemoveProfile; break;
        case 14: *reinterpret_cast<bool*>(_v) = _t->m_profileHasDisplayCorrection; break;
        default: break;
        }
    }
    if (_c == QMetaObject::WriteProperty) {
        void *_v = _a[0];
        switch (_id) {
        case 2:
            if (QtMocHelpers::setProperty(_t->m_currentProfilePath, *reinterpret_cast<QDBusObjectPath*>(_v)))
                Q_EMIT _t->dataChanged();
            break;
        case 3:
            if (QtMocHelpers::setProperty(_t->m_profileKind, *reinterpret_cast<QString*>(_v)))
                Q_EMIT _t->dataChanged();
            break;
        case 4:
            if (QtMocHelpers::setProperty(_t->m_profileColorSpace, *reinterpret_cast<QString*>(_v)))
                Q_EMIT _t->dataChanged();
            break;
        case 5:
            if (QtMocHelpers::setProperty(_t->m_profileVersion, *reinterpret_cast<QString*>(_v)))
                Q_EMIT _t->dataChanged();
            break;
        case 6:
            if (QtMocHelpers::setProperty(_t->m_profileCreatedTime, *reinterpret_cast<QString*>(_v)))
                Q_EMIT _t->dataChanged();
            break;
        case 7:
            if (QtMocHelpers::setProperty(_t->m_profileLicense, *reinterpret_cast<QString*>(_v)))
                Q_EMIT _t->dataChanged();
            break;
        case 8:
            if (QtMocHelpers::setProperty(_t->m_profileManufacturer, *reinterpret_cast<QString*>(_v)))
                Q_EMIT _t->dataChanged();
            break;
        case 9:
            if (QtMocHelpers::setProperty(_t->m_profileModel, *reinterpret_cast<QString*>(_v)))
                Q_EMIT _t->dataChanged();
            break;
        case 10:
            if (QtMocHelpers::setProperty(_t->m_profileSize, *reinterpret_cast<QString*>(_v)))
                Q_EMIT _t->dataChanged();
            break;
        case 11:
            if (QtMocHelpers::setProperty(_t->m_profileName, *reinterpret_cast<QString*>(_v)))
                Q_EMIT _t->dataChanged();
            break;
        case 12:
            if (QtMocHelpers::setProperty(_t->m_profileWhitePoint, *reinterpret_cast<QString*>(_v)))
                Q_EMIT _t->dataChanged();
            break;
        case 13:
            if (QtMocHelpers::setProperty(_t->m_canRemoveProfile, *reinterpret_cast<bool*>(_v)))
                Q_EMIT _t->dataChanged();
            break;
        case 14:
            if (QtMocHelpers::setProperty(_t->m_profileHasDisplayCorrection, *reinterpret_cast<bool*>(_v)))
                Q_EMIT _t->dataChanged();
            break;
        default: break;
        }
    }
}

const QMetaObject *ProfileDescription::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *ProfileDescription::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_staticMetaObjectStaticContent<qt_meta_tag_ZN18ProfileDescriptionE_t>.strings))
        return static_cast<void*>(this);
    return QObject::qt_metacast(_clname);
}

int ProfileDescription::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = QObject::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 3)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 3;
    }
    if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 3)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 3;
    }
    if (_c == QMetaObject::ReadProperty || _c == QMetaObject::WriteProperty
            || _c == QMetaObject::ResetProperty || _c == QMetaObject::BindableProperty
            || _c == QMetaObject::RegisterPropertyMetaType) {
        qt_static_metacall(this, _c, _id, _a);
        _id -= 15;
    }
    return _id;
}

// SIGNAL 0
void ProfileDescription::dataChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 0, nullptr);
}
QT_WARNING_POP
