/****************************************************************************
** Meta object code from reading C++ file 'CdInterface.h'
**
** Created by: The Qt Meta Object Compiler version 69 (Qt 6.11.1)
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#include "CdInterface.h"
#include <QtCore/qmetatype.h>

#include <QtCore/qtmochelpers.h>

#include <memory>


#include <QtCore/qxptype_traits.h>
#if !defined(Q_MOC_OUTPUT_REVISION)
#error "The header file 'CdInterface.h' doesn't include <QObject>."
#elif Q_MOC_OUTPUT_REVISION != 69
#error "This file was generated using the moc from 6.11.1. It"
#error "cannot be used with the include files from this version of Qt."
#error "(The moc has changed too much.)"
#endif

#ifndef Q_CONSTINIT
#define Q_CONSTINIT
#endif

QT_WARNING_PUSH
QT_WARNING_DISABLE_DEPRECATED
QT_WARNING_DISABLE_GCC("-Wuseless-cast")
namespace {
struct qt_meta_tag_ZN11CdInterfaceE_t {};
} // unnamed namespace

template <> constexpr inline auto CdInterface::qt_create_metaobjectdata<qt_meta_tag_ZN11CdInterfaceE_t>()
{
    namespace QMC = QtMocConstants;
    QtMocHelpers::StringRefStorage qt_stringData {
        "CdInterface",
        "Changed",
        "",
        "DeviceAdded",
        "QDBusObjectPath",
        "object_path",
        "DeviceChanged",
        "DeviceRemoved",
        "ProfileAdded",
        "ProfileChanged",
        "ProfileRemoved",
        "SensorAdded",
        "SensorRemoved",
        "CreateDevice",
        "QDBusPendingReply<QDBusObjectPath>",
        "device_id",
        "scope",
        "CdStringMap",
        "properties",
        "CreateProfile",
        "profile_id",
        "CreateProfileWithFd",
        "QDBusUnixFileDescriptor",
        "handle",
        "DeleteDevice",
        "QDBusPendingReply<>",
        "DeleteProfile",
        "FindDeviceById",
        "FindDeviceByProperty",
        "key",
        "value",
        "FindProfileByFilename",
        "filename",
        "FindProfileById",
        "FindProfileByProperty",
        "FindSensorById",
        "sensor_id",
        "GetDevices",
        "QDBusPendingReply<QList<QDBusObjectPath>>",
        "GetDevicesByKind",
        "kind",
        "GetProfiles",
        "GetProfilesByKind",
        "GetSensors",
        "GetStandardSpace",
        "standard_space",
        "DaemonVersion",
        "SystemModel",
        "SystemVendor"
    };

    QtMocHelpers::UintData qt_methods {
        // Signal 'Changed'
        QtMocHelpers::SignalData<void()>(1, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'DeviceAdded'
        QtMocHelpers::SignalData<void(const QDBusObjectPath &)>(3, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 4, 5 },
        }}),
        // Signal 'DeviceChanged'
        QtMocHelpers::SignalData<void(const QDBusObjectPath &)>(6, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 4, 5 },
        }}),
        // Signal 'DeviceRemoved'
        QtMocHelpers::SignalData<void(const QDBusObjectPath &)>(7, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 4, 5 },
        }}),
        // Signal 'ProfileAdded'
        QtMocHelpers::SignalData<void(const QDBusObjectPath &)>(8, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 4, 5 },
        }}),
        // Signal 'ProfileChanged'
        QtMocHelpers::SignalData<void(const QDBusObjectPath &)>(9, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 4, 5 },
        }}),
        // Signal 'ProfileRemoved'
        QtMocHelpers::SignalData<void(const QDBusObjectPath &)>(10, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 4, 5 },
        }}),
        // Signal 'SensorAdded'
        QtMocHelpers::SignalData<void(const QDBusObjectPath &)>(11, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 4, 5 },
        }}),
        // Signal 'SensorRemoved'
        QtMocHelpers::SignalData<void(const QDBusObjectPath &)>(12, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 4, 5 },
        }}),
        // Slot 'CreateDevice'
        QtMocHelpers::SlotData<QDBusPendingReply<QDBusObjectPath>(const QString &, const QString &, CdStringMap)>(13, 2, QMC::AccessPublic, 0x80000000 | 14, {{
            { QMetaType::QString, 15 }, { QMetaType::QString, 16 }, { 0x80000000 | 17, 18 },
        }}),
        // Slot 'CreateProfile'
        QtMocHelpers::SlotData<QDBusPendingReply<QDBusObjectPath>(const QString &, const QString &, CdStringMap)>(19, 2, QMC::AccessPublic, 0x80000000 | 14, {{
            { QMetaType::QString, 20 }, { QMetaType::QString, 16 }, { 0x80000000 | 17, 18 },
        }}),
        // Slot 'CreateProfileWithFd'
        QtMocHelpers::SlotData<QDBusPendingReply<QDBusObjectPath>(const QString &, const QString &, const QDBusUnixFileDescriptor &, CdStringMap)>(21, 2, QMC::AccessPublic, 0x80000000 | 14, {{
            { QMetaType::QString, 20 }, { QMetaType::QString, 16 }, { 0x80000000 | 22, 23 }, { 0x80000000 | 17, 18 },
        }}),
        // Slot 'DeleteDevice'
        QtMocHelpers::SlotData<QDBusPendingReply<>(const QDBusObjectPath &)>(24, 2, QMC::AccessPublic, 0x80000000 | 25, {{
            { 0x80000000 | 4, 5 },
        }}),
        // Slot 'DeleteProfile'
        QtMocHelpers::SlotData<QDBusPendingReply<>(const QDBusObjectPath &)>(26, 2, QMC::AccessPublic, 0x80000000 | 25, {{
            { 0x80000000 | 4, 5 },
        }}),
        // Slot 'FindDeviceById'
        QtMocHelpers::SlotData<QDBusPendingReply<QDBusObjectPath>(const QString &)>(27, 2, QMC::AccessPublic, 0x80000000 | 14, {{
            { QMetaType::QString, 15 },
        }}),
        // Slot 'FindDeviceByProperty'
        QtMocHelpers::SlotData<QDBusPendingReply<QDBusObjectPath>(const QString &, const QString &)>(28, 2, QMC::AccessPublic, 0x80000000 | 14, {{
            { QMetaType::QString, 29 }, { QMetaType::QString, 30 },
        }}),
        // Slot 'FindProfileByFilename'
        QtMocHelpers::SlotData<QDBusPendingReply<QDBusObjectPath>(const QString &)>(31, 2, QMC::AccessPublic, 0x80000000 | 14, {{
            { QMetaType::QString, 32 },
        }}),
        // Slot 'FindProfileById'
        QtMocHelpers::SlotData<QDBusPendingReply<QDBusObjectPath>(const QString &)>(33, 2, QMC::AccessPublic, 0x80000000 | 14, {{
            { QMetaType::QString, 20 },
        }}),
        // Slot 'FindProfileByProperty'
        QtMocHelpers::SlotData<QDBusPendingReply<QDBusObjectPath>(const QString &, const QString &)>(34, 2, QMC::AccessPublic, 0x80000000 | 14, {{
            { QMetaType::QString, 29 }, { QMetaType::QString, 30 },
        }}),
        // Slot 'FindSensorById'
        QtMocHelpers::SlotData<QDBusPendingReply<QDBusObjectPath>(const QString &)>(35, 2, QMC::AccessPublic, 0x80000000 | 14, {{
            { QMetaType::QString, 36 },
        }}),
        // Slot 'GetDevices'
        QtMocHelpers::SlotData<QDBusPendingReply<QList<QDBusObjectPath> >()>(37, 2, QMC::AccessPublic, 0x80000000 | 38),
        // Slot 'GetDevicesByKind'
        QtMocHelpers::SlotData<QDBusPendingReply<QList<QDBusObjectPath> >(const QString &)>(39, 2, QMC::AccessPublic, 0x80000000 | 38, {{
            { QMetaType::QString, 40 },
        }}),
        // Slot 'GetProfiles'
        QtMocHelpers::SlotData<QDBusPendingReply<QList<QDBusObjectPath> >()>(41, 2, QMC::AccessPublic, 0x80000000 | 38),
        // Slot 'GetProfilesByKind'
        QtMocHelpers::SlotData<QDBusPendingReply<QList<QDBusObjectPath> >(const QString &)>(42, 2, QMC::AccessPublic, 0x80000000 | 38, {{
            { QMetaType::QString, 40 },
        }}),
        // Slot 'GetSensors'
        QtMocHelpers::SlotData<QDBusPendingReply<QList<QDBusObjectPath> >()>(43, 2, QMC::AccessPublic, 0x80000000 | 38),
        // Slot 'GetStandardSpace'
        QtMocHelpers::SlotData<QDBusPendingReply<QDBusObjectPath>(const QString &)>(44, 2, QMC::AccessPublic, 0x80000000 | 14, {{
            { QMetaType::QString, 45 },
        }}),
    };
    QtMocHelpers::UintData qt_properties {
        // property 'DaemonVersion'
        QtMocHelpers::PropertyData<QString>(46, QMetaType::QString, QMC::DefaultPropertyFlags),
        // property 'SystemModel'
        QtMocHelpers::PropertyData<QString>(47, QMetaType::QString, QMC::DefaultPropertyFlags),
        // property 'SystemVendor'
        QtMocHelpers::PropertyData<QString>(48, QMetaType::QString, QMC::DefaultPropertyFlags),
    };
    QtMocHelpers::UintData qt_enums {
    };
    return QtMocHelpers::metaObjectData<CdInterface, qt_meta_tag_ZN11CdInterfaceE_t>(QMC::MetaObjectFlag{}, qt_stringData,
            qt_methods, qt_properties, qt_enums);
}
Q_CONSTINIT const QMetaObject CdInterface::staticMetaObject = { {
    QMetaObject::SuperData::link<QDBusAbstractInterface::staticMetaObject>(),
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN11CdInterfaceE_t>.stringdata,
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN11CdInterfaceE_t>.data,
    qt_static_metacall,
    nullptr,
    qt_staticMetaObjectRelocatingContent<qt_meta_tag_ZN11CdInterfaceE_t>.metaTypes,
    nullptr
} };

void CdInterface::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    auto *_t = static_cast<CdInterface *>(_o);
    if (_c == QMetaObject::InvokeMetaMethod) {
        switch (_id) {
        case 0: _t->Changed(); break;
        case 1: _t->DeviceAdded((*reinterpret_cast<std::add_pointer_t<QDBusObjectPath>>(_a[1]))); break;
        case 2: _t->DeviceChanged((*reinterpret_cast<std::add_pointer_t<QDBusObjectPath>>(_a[1]))); break;
        case 3: _t->DeviceRemoved((*reinterpret_cast<std::add_pointer_t<QDBusObjectPath>>(_a[1]))); break;
        case 4: _t->ProfileAdded((*reinterpret_cast<std::add_pointer_t<QDBusObjectPath>>(_a[1]))); break;
        case 5: _t->ProfileChanged((*reinterpret_cast<std::add_pointer_t<QDBusObjectPath>>(_a[1]))); break;
        case 6: _t->ProfileRemoved((*reinterpret_cast<std::add_pointer_t<QDBusObjectPath>>(_a[1]))); break;
        case 7: _t->SensorAdded((*reinterpret_cast<std::add_pointer_t<QDBusObjectPath>>(_a[1]))); break;
        case 8: _t->SensorRemoved((*reinterpret_cast<std::add_pointer_t<QDBusObjectPath>>(_a[1]))); break;
        case 9: { QDBusPendingReply<QDBusObjectPath> _r = _t->CreateDevice((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QString>>(_a[2])),(*reinterpret_cast<std::add_pointer_t<CdStringMap>>(_a[3])));
            if (_a[0]) *reinterpret_cast<QDBusPendingReply<QDBusObjectPath>*>(_a[0]) = std::move(_r); }  break;
        case 10: { QDBusPendingReply<QDBusObjectPath> _r = _t->CreateProfile((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QString>>(_a[2])),(*reinterpret_cast<std::add_pointer_t<CdStringMap>>(_a[3])));
            if (_a[0]) *reinterpret_cast<QDBusPendingReply<QDBusObjectPath>*>(_a[0]) = std::move(_r); }  break;
        case 11: { QDBusPendingReply<QDBusObjectPath> _r = _t->CreateProfileWithFd((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QString>>(_a[2])),(*reinterpret_cast<std::add_pointer_t<QDBusUnixFileDescriptor>>(_a[3])),(*reinterpret_cast<std::add_pointer_t<CdStringMap>>(_a[4])));
            if (_a[0]) *reinterpret_cast<QDBusPendingReply<QDBusObjectPath>*>(_a[0]) = std::move(_r); }  break;
        case 12: { QDBusPendingReply<> _r = _t->DeleteDevice((*reinterpret_cast<std::add_pointer_t<QDBusObjectPath>>(_a[1])));
            if (_a[0]) *reinterpret_cast<QDBusPendingReply<>*>(_a[0]) = std::move(_r); }  break;
        case 13: { QDBusPendingReply<> _r = _t->DeleteProfile((*reinterpret_cast<std::add_pointer_t<QDBusObjectPath>>(_a[1])));
            if (_a[0]) *reinterpret_cast<QDBusPendingReply<>*>(_a[0]) = std::move(_r); }  break;
        case 14: { QDBusPendingReply<QDBusObjectPath> _r = _t->FindDeviceById((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1])));
            if (_a[0]) *reinterpret_cast<QDBusPendingReply<QDBusObjectPath>*>(_a[0]) = std::move(_r); }  break;
        case 15: { QDBusPendingReply<QDBusObjectPath> _r = _t->FindDeviceByProperty((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QString>>(_a[2])));
            if (_a[0]) *reinterpret_cast<QDBusPendingReply<QDBusObjectPath>*>(_a[0]) = std::move(_r); }  break;
        case 16: { QDBusPendingReply<QDBusObjectPath> _r = _t->FindProfileByFilename((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1])));
            if (_a[0]) *reinterpret_cast<QDBusPendingReply<QDBusObjectPath>*>(_a[0]) = std::move(_r); }  break;
        case 17: { QDBusPendingReply<QDBusObjectPath> _r = _t->FindProfileById((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1])));
            if (_a[0]) *reinterpret_cast<QDBusPendingReply<QDBusObjectPath>*>(_a[0]) = std::move(_r); }  break;
        case 18: { QDBusPendingReply<QDBusObjectPath> _r = _t->FindProfileByProperty((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QString>>(_a[2])));
            if (_a[0]) *reinterpret_cast<QDBusPendingReply<QDBusObjectPath>*>(_a[0]) = std::move(_r); }  break;
        case 19: { QDBusPendingReply<QDBusObjectPath> _r = _t->FindSensorById((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1])));
            if (_a[0]) *reinterpret_cast<QDBusPendingReply<QDBusObjectPath>*>(_a[0]) = std::move(_r); }  break;
        case 20: { QDBusPendingReply<QList<QDBusObjectPath>> _r = _t->GetDevices();
            if (_a[0]) *reinterpret_cast<QDBusPendingReply<QList<QDBusObjectPath>>*>(_a[0]) = std::move(_r); }  break;
        case 21: { QDBusPendingReply<QList<QDBusObjectPath>> _r = _t->GetDevicesByKind((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1])));
            if (_a[0]) *reinterpret_cast<QDBusPendingReply<QList<QDBusObjectPath>>*>(_a[0]) = std::move(_r); }  break;
        case 22: { QDBusPendingReply<QList<QDBusObjectPath>> _r = _t->GetProfiles();
            if (_a[0]) *reinterpret_cast<QDBusPendingReply<QList<QDBusObjectPath>>*>(_a[0]) = std::move(_r); }  break;
        case 23: { QDBusPendingReply<QList<QDBusObjectPath>> _r = _t->GetProfilesByKind((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1])));
            if (_a[0]) *reinterpret_cast<QDBusPendingReply<QList<QDBusObjectPath>>*>(_a[0]) = std::move(_r); }  break;
        case 24: { QDBusPendingReply<QList<QDBusObjectPath>> _r = _t->GetSensors();
            if (_a[0]) *reinterpret_cast<QDBusPendingReply<QList<QDBusObjectPath>>*>(_a[0]) = std::move(_r); }  break;
        case 25: { QDBusPendingReply<QDBusObjectPath> _r = _t->GetStandardSpace((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1])));
            if (_a[0]) *reinterpret_cast<QDBusPendingReply<QDBusObjectPath>*>(_a[0]) = std::move(_r); }  break;
        default: ;
        }
    }
    if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        switch (_id) {
        default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
        case 9:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
            case 2:
                *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType::fromType< CdStringMap >(); break;
            }
            break;
        case 10:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
            case 2:
                *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType::fromType< CdStringMap >(); break;
            }
            break;
        case 11:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
            case 3:
                *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType::fromType< CdStringMap >(); break;
            }
            break;
        }
    }
    if (_c == QMetaObject::IndexOfMethod) {
        if (QtMocHelpers::indexOfMethod<void (CdInterface::*)()>(_a, &CdInterface::Changed, 0))
            return;
        if (QtMocHelpers::indexOfMethod<void (CdInterface::*)(const QDBusObjectPath & )>(_a, &CdInterface::DeviceAdded, 1))
            return;
        if (QtMocHelpers::indexOfMethod<void (CdInterface::*)(const QDBusObjectPath & )>(_a, &CdInterface::DeviceChanged, 2))
            return;
        if (QtMocHelpers::indexOfMethod<void (CdInterface::*)(const QDBusObjectPath & )>(_a, &CdInterface::DeviceRemoved, 3))
            return;
        if (QtMocHelpers::indexOfMethod<void (CdInterface::*)(const QDBusObjectPath & )>(_a, &CdInterface::ProfileAdded, 4))
            return;
        if (QtMocHelpers::indexOfMethod<void (CdInterface::*)(const QDBusObjectPath & )>(_a, &CdInterface::ProfileChanged, 5))
            return;
        if (QtMocHelpers::indexOfMethod<void (CdInterface::*)(const QDBusObjectPath & )>(_a, &CdInterface::ProfileRemoved, 6))
            return;
        if (QtMocHelpers::indexOfMethod<void (CdInterface::*)(const QDBusObjectPath & )>(_a, &CdInterface::SensorAdded, 7))
            return;
        if (QtMocHelpers::indexOfMethod<void (CdInterface::*)(const QDBusObjectPath & )>(_a, &CdInterface::SensorRemoved, 8))
            return;
    }
    if (_c == QMetaObject::ReadProperty) {
        void *_v = _a[0];
        switch (_id) {
        case 0: *reinterpret_cast<QString*>(_v) = _t->daemonVersion(); break;
        case 1: *reinterpret_cast<QString*>(_v) = _t->systemModel(); break;
        case 2: *reinterpret_cast<QString*>(_v) = _t->systemVendor(); break;
        default: break;
        }
    }
}

const QMetaObject *CdInterface::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *CdInterface::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_staticMetaObjectStaticContent<qt_meta_tag_ZN11CdInterfaceE_t>.strings))
        return static_cast<void*>(this);
    return QDBusAbstractInterface::qt_metacast(_clname);
}

int CdInterface::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = QDBusAbstractInterface::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 26)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 26;
    }
    if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 26)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 26;
    }
    if (_c == QMetaObject::ReadProperty || _c == QMetaObject::WriteProperty
            || _c == QMetaObject::ResetProperty || _c == QMetaObject::BindableProperty
            || _c == QMetaObject::RegisterPropertyMetaType) {
        qt_static_metacall(this, _c, _id, _a);
        _id -= 3;
    }
    return _id;
}

// SIGNAL 0
void CdInterface::Changed()
{
    QMetaObject::activate(this, &staticMetaObject, 0, nullptr);
}

// SIGNAL 1
void CdInterface::DeviceAdded(const QDBusObjectPath & _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 1, nullptr, _t1);
}

// SIGNAL 2
void CdInterface::DeviceChanged(const QDBusObjectPath & _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 2, nullptr, _t1);
}

// SIGNAL 3
void CdInterface::DeviceRemoved(const QDBusObjectPath & _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 3, nullptr, _t1);
}

// SIGNAL 4
void CdInterface::ProfileAdded(const QDBusObjectPath & _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 4, nullptr, _t1);
}

// SIGNAL 5
void CdInterface::ProfileChanged(const QDBusObjectPath & _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 5, nullptr, _t1);
}

// SIGNAL 6
void CdInterface::ProfileRemoved(const QDBusObjectPath & _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 6, nullptr, _t1);
}

// SIGNAL 7
void CdInterface::SensorAdded(const QDBusObjectPath & _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 7, nullptr, _t1);
}

// SIGNAL 8
void CdInterface::SensorRemoved(const QDBusObjectPath & _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 8, nullptr, _t1);
}
QT_WARNING_POP
