/****************************************************************************
** Meta object code from reading C++ file 'CdSensorInterface.h'
**
** Created by: The Qt Meta Object Compiler version 69 (Qt 6.11.1)
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#include "CdSensorInterface.h"
#include <QtCore/qmetatype.h>

#include <QtCore/qtmochelpers.h>

#include <memory>


#include <QtCore/qxptype_traits.h>
#if !defined(Q_MOC_OUTPUT_REVISION)
#error "The header file 'CdSensorInterface.h' doesn't include <QObject>."
#elif Q_MOC_OUTPUT_REVISION != 69
#error "This file was generated using the moc from 6.11.1. It"
#error "cannot be used with the include files from this version of Qt."
#error "(The moc has changed too much.)"
#endif

#ifndef Q_CONSTINIT
#define Q_CONSTINIT
#endif

QT_WARNING_PUSH
QT_WARNING_DISABLE_DEPRECATED
QT_WARNING_DISABLE_GCC("-Wuseless-cast")
namespace {
struct qt_meta_tag_ZN17CdSensorInterfaceE_t {};
} // unnamed namespace

template <> constexpr inline auto CdSensorInterface::qt_create_metaobjectdata<qt_meta_tag_ZN17CdSensorInterfaceE_t>()
{
    namespace QMC = QtMocConstants;
    QtMocHelpers::StringRefStorage qt_stringData {
        "CdSensorInterface",
        "ButtonPressed",
        "",
        "GetSample",
        "QDBusPendingReply<double,double,double>",
        "capability",
        "QDBusReply<double>",
        "double&",
        "sample_y",
        "sample_z",
        "Lock",
        "QDBusPendingReply<>",
        "SetOptions",
        "QVariantMap",
        "values",
        "Unlock",
        "Capabilities",
        "Embedded",
        "Kind",
        "Locked",
        "Metadata",
        "CdStringMap",
        "Mode",
        "Model",
        "Native",
        "Options",
        "SensorId",
        "Serial",
        "State",
        "Vendor"
    };

    QtMocHelpers::UintData qt_methods {
        // Signal 'ButtonPressed'
        QtMocHelpers::SignalData<void()>(1, 2, QMC::AccessPublic, QMetaType::Void),
        // Slot 'GetSample'
        QtMocHelpers::SlotData<QDBusPendingReply<double,double,double>(const QString &)>(3, 2, QMC::AccessPublic, 0x80000000 | 4, {{
            { QMetaType::QString, 5 },
        }}),
        // Slot 'GetSample'
        QtMocHelpers::SlotData<QDBusReply<double>(const QString &, double &, double &)>(3, 2, QMC::AccessPublic, 0x80000000 | 6, {{
            { QMetaType::QString, 5 }, { 0x80000000 | 7, 8 }, { 0x80000000 | 7, 9 },
        }}),
        // Slot 'Lock'
        QtMocHelpers::SlotData<QDBusPendingReply<>()>(10, 2, QMC::AccessPublic, 0x80000000 | 11),
        // Slot 'SetOptions'
        QtMocHelpers::SlotData<QDBusPendingReply<>(const QVariantMap &)>(12, 2, QMC::AccessPublic, 0x80000000 | 11, {{
            { 0x80000000 | 13, 14 },
        }}),
        // Slot 'Unlock'
        QtMocHelpers::SlotData<QDBusPendingReply<>()>(15, 2, QMC::AccessPublic, 0x80000000 | 11),
    };
    QtMocHelpers::UintData qt_properties {
        // property 'Capabilities'
        QtMocHelpers::PropertyData<QStringList>(16, QMetaType::QStringList, QMC::DefaultPropertyFlags),
        // property 'Embedded'
        QtMocHelpers::PropertyData<bool>(17, QMetaType::Bool, QMC::DefaultPropertyFlags),
        // property 'Kind'
        QtMocHelpers::PropertyData<QString>(18, QMetaType::QString, QMC::DefaultPropertyFlags),
        // property 'Locked'
        QtMocHelpers::PropertyData<bool>(19, QMetaType::Bool, QMC::DefaultPropertyFlags),
        // property 'Metadata'
        QtMocHelpers::PropertyData<CdStringMap>(20, 0x80000000 | 21, QMC::DefaultPropertyFlags | QMC::EnumOrFlag),
        // property 'Mode'
        QtMocHelpers::PropertyData<QString>(22, QMetaType::QString, QMC::DefaultPropertyFlags),
        // property 'Model'
        QtMocHelpers::PropertyData<QString>(23, QMetaType::QString, QMC::DefaultPropertyFlags),
        // property 'Native'
        QtMocHelpers::PropertyData<bool>(24, QMetaType::Bool, QMC::DefaultPropertyFlags),
        // property 'Options'
        QtMocHelpers::PropertyData<QVariantMap>(25, 0x80000000 | 13, QMC::DefaultPropertyFlags | QMC::EnumOrFlag),
        // property 'SensorId'
        QtMocHelpers::PropertyData<QString>(26, QMetaType::QString, QMC::DefaultPropertyFlags),
        // property 'Serial'
        QtMocHelpers::PropertyData<QString>(27, QMetaType::QString, QMC::DefaultPropertyFlags),
        // property 'State'
        QtMocHelpers::PropertyData<QString>(28, QMetaType::QString, QMC::DefaultPropertyFlags),
        // property 'Vendor'
        QtMocHelpers::PropertyData<QString>(29, QMetaType::QString, QMC::DefaultPropertyFlags),
    };
    QtMocHelpers::UintData qt_enums {
    };
    return QtMocHelpers::metaObjectData<CdSensorInterface, qt_meta_tag_ZN17CdSensorInterfaceE_t>(QMC::MetaObjectFlag{}, qt_stringData,
            qt_methods, qt_properties, qt_enums);
}
Q_CONSTINIT const QMetaObject CdSensorInterface::staticMetaObject = { {
    QMetaObject::SuperData::link<QDBusAbstractInterface::staticMetaObject>(),
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN17CdSensorInterfaceE_t>.stringdata,
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN17CdSensorInterfaceE_t>.data,
    qt_static_metacall,
    nullptr,
    qt_staticMetaObjectRelocatingContent<qt_meta_tag_ZN17CdSensorInterfaceE_t>.metaTypes,
    nullptr
} };

void CdSensorInterface::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    auto *_t = static_cast<CdSensorInterface *>(_o);
    if (_c == QMetaObject::InvokeMetaMethod) {
        switch (_id) {
        case 0: _t->ButtonPressed(); break;
        case 1: { QDBusPendingReply<double,double,double> _r = _t->GetSample((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1])));
            if (_a[0]) *reinterpret_cast<QDBusPendingReply<double,double,double>*>(_a[0]) = std::move(_r); }  break;
        case 2: { QDBusReply<double> _r = _t->GetSample((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<double&>>(_a[2])),(*reinterpret_cast<std::add_pointer_t<double&>>(_a[3])));
            if (_a[0]) *reinterpret_cast<QDBusReply<double>*>(_a[0]) = std::move(_r); }  break;
        case 3: { QDBusPendingReply<> _r = _t->Lock();
            if (_a[0]) *reinterpret_cast<QDBusPendingReply<>*>(_a[0]) = std::move(_r); }  break;
        case 4: { QDBusPendingReply<> _r = _t->SetOptions((*reinterpret_cast<std::add_pointer_t<QVariantMap>>(_a[1])));
            if (_a[0]) *reinterpret_cast<QDBusPendingReply<>*>(_a[0]) = std::move(_r); }  break;
        case 5: { QDBusPendingReply<> _r = _t->Unlock();
            if (_a[0]) *reinterpret_cast<QDBusPendingReply<>*>(_a[0]) = std::move(_r); }  break;
        default: ;
        }
    }
    if (_c == QMetaObject::IndexOfMethod) {
        if (QtMocHelpers::indexOfMethod<void (CdSensorInterface::*)()>(_a, &CdSensorInterface::ButtonPressed, 0))
            return;
    }
    if (_c == QMetaObject::RegisterPropertyMetaType) {
        switch (_id) {
        default: *reinterpret_cast<int*>(_a[0]) = -1; break;
        case 4:
            *reinterpret_cast<int*>(_a[0]) = qRegisterMetaType< CdStringMap >(); break;
        }
    }
    if (_c == QMetaObject::ReadProperty) {
        void *_v = _a[0];
        switch (_id) {
        case 0: *reinterpret_cast<QStringList*>(_v) = _t->capabilities(); break;
        case 1: *reinterpret_cast<bool*>(_v) = _t->embedded(); break;
        case 2: *reinterpret_cast<QString*>(_v) = _t->kind(); break;
        case 3: *reinterpret_cast<bool*>(_v) = _t->locked(); break;
        case 4: *reinterpret_cast<CdStringMap*>(_v) = _t->metadata(); break;
        case 5: *reinterpret_cast<QString*>(_v) = _t->mode(); break;
        case 6: *reinterpret_cast<QString*>(_v) = _t->model(); break;
        case 7: *reinterpret_cast<bool*>(_v) = _t->native(); break;
        case 8: *reinterpret_cast<QVariantMap*>(_v) = _t->options(); break;
        case 9: *reinterpret_cast<QString*>(_v) = _t->sensorId(); break;
        case 10: *reinterpret_cast<QString*>(_v) = _t->serial(); break;
        case 11: *reinterpret_cast<QString*>(_v) = _t->state(); break;
        case 12: *reinterpret_cast<QString*>(_v) = _t->vendor(); break;
        default: break;
        }
    }
}

const QMetaObject *CdSensorInterface::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *CdSensorInterface::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_staticMetaObjectStaticContent<qt_meta_tag_ZN17CdSensorInterfaceE_t>.strings))
        return static_cast<void*>(this);
    return QDBusAbstractInterface::qt_metacast(_clname);
}

int CdSensorInterface::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = QDBusAbstractInterface::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 6)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 6;
    }
    if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 6)
            *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType();
        _id -= 6;
    }
    if (_c == QMetaObject::ReadProperty || _c == QMetaObject::WriteProperty
            || _c == QMetaObject::ResetProperty || _c == QMetaObject::BindableProperty
            || _c == QMetaObject::RegisterPropertyMetaType) {
        qt_static_metacall(this, _c, _id, _a);
        _id -= 13;
    }
    return _id;
}

// SIGNAL 0
void CdSensorInterface::ButtonPressed()
{
    QMetaObject::activate(this, &staticMetaObject, 0, nullptr);
}
QT_WARNING_POP
