/*
 * This file was generated by qdbusxml2cpp version 0.8
 * Source file was org.freedesktop.ColorManager.Sensor.xml
 *
 * qdbusxml2cpp is Copyright (C) The Qt Company Ltd. and other contributors.
 *
 * This is an auto-generated file.
 * Do not edit! All changes made to it will be lost.
 */

#ifndef CDSENSORINTERFACE_H
#define CDSENSORINTERFACE_H

#include <QtCore/QObject>
#include <QtCore/QByteArray>
#include <QtCore/QList>
#include <QtCore/QMap>
#include <QtCore/QString>
#include <QtCore/QStringList>
#include <QtCore/QVariant>
#include <QtDBus/QtDBus>
#include "dbus-types.h"

/*
 * Proxy class for interface org.freedesktop.ColorManager.Sensor
 */
class CdSensorInterface: public QDBusAbstractInterface
{
    Q_OBJECT
public:
    static inline const char *staticInterfaceName()
    { return "org.freedesktop.ColorManager.Sensor"; }

public:
    CdSensorInterface(const QString &service, const QString &path, const QDBusConnection &connection, QObject *parent = nullptr);

    ~CdSensorInterface();

    Q_PROPERTY(QStringList Capabilities READ capabilities)
    inline QStringList capabilities() const
    { return qvariant_cast< QStringList >(property("Capabilities")); }

    Q_PROPERTY(bool Embedded READ embedded)
    inline bool embedded() const
    { return qvariant_cast< bool >(property("Embedded")); }

    Q_PROPERTY(QString Kind READ kind)
    inline QString kind() const
    { return qvariant_cast< QString >(property("Kind")); }

    Q_PROPERTY(bool Locked READ locked)
    inline bool locked() const
    { return qvariant_cast< bool >(property("Locked")); }

    Q_PROPERTY(CdStringMap Metadata READ metadata)
    inline CdStringMap metadata() const
    { return qvariant_cast< CdStringMap >(property("Metadata")); }

    Q_PROPERTY(QString Mode READ mode)
    inline QString mode() const
    { return qvariant_cast< QString >(property("Mode")); }

    Q_PROPERTY(QString Model READ model)
    inline QString model() const
    { return qvariant_cast< QString >(property("Model")); }

    Q_PROPERTY(bool Native READ native)
    inline bool native() const
    { return qvariant_cast< bool >(property("Native")); }

    Q_PROPERTY(QVariantMap Options READ options)
    inline QVariantMap options() const
    { return qvariant_cast< QVariantMap >(property("Options")); }

    Q_PROPERTY(QString SensorId READ sensorId)
    inline QString sensorId() const
    { return qvariant_cast< QString >(property("SensorId")); }

    Q_PROPERTY(QString Serial READ serial)
    inline QString serial() const
    { return qvariant_cast< QString >(property("Serial")); }

    Q_PROPERTY(QString State READ state)
    inline QString state() const
    { return qvariant_cast< QString >(property("State")); }

    Q_PROPERTY(QString Vendor READ vendor)
    inline QString vendor() const
    { return qvariant_cast< QString >(property("Vendor")); }

public Q_SLOTS: // METHODS
    inline QDBusPendingReply<double, double, double> GetSample(const QString &capability)
    {
        QList<QVariant> argumentList;
        argumentList << QVariant::fromValue(capability);
        return asyncCallWithArgumentList(QStringLiteral("GetSample"), argumentList);
    }
    inline QDBusReply<double> GetSample(const QString &capability, double &sample_y, double &sample_z)
    {
        QList<QVariant> argumentList;
        argumentList << QVariant::fromValue(capability);
        QDBusMessage reply = callWithArgumentList(QDBus::Block, QStringLiteral("GetSample"), argumentList);
        if (reply.type() == QDBusMessage::ReplyMessage && reply.arguments().size() == 3) {
            sample_y = qdbus_cast<double>(reply.arguments().at(1));
            sample_z = qdbus_cast<double>(reply.arguments().at(2));
        }
        return reply;
    }

    inline QDBusPendingReply<> Lock()
    {
        QList<QVariant> argumentList;
        return asyncCallWithArgumentList(QStringLiteral("Lock"), argumentList);
    }

    inline QDBusPendingReply<> SetOptions(const QVariantMap &values)
    {
        QList<QVariant> argumentList;
        argumentList << QVariant::fromValue(values);
        return asyncCallWithArgumentList(QStringLiteral("SetOptions"), argumentList);
    }

    inline QDBusPendingReply<> Unlock()
    {
        QList<QVariant> argumentList;
        return asyncCallWithArgumentList(QStringLiteral("Unlock"), argumentList);
    }

Q_SIGNALS: // SIGNALS
    void ButtonPressed();
};

#endif
